@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Log::Dispatchouli::Global 3.003;
+package Log::Dispatchouli::Global 3.004;
 # ABSTRACT: a system for sharing a global, dynamically-scoped logger
 
 use Carp ();
@@ -280,7 +280,7 @@ Log::Dispatchouli::Global - a system for sharing a global, dynamically-scoped lo
 
 =head1 VERSION
 
-version 3.003
+version 3.004
 
 =head1 DESCRIPTION
 
@@ -331,13 +331,13 @@ control is dangerous>.
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should
-work on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to
-lower the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 USING
 
