@@ -1,6 +1,6 @@
 use v5.20;
 use warnings;
-package Log::Fmt 3.003;
+package Log::Fmt 3.004;
 # ABSTRACT: a little parser and emitter of structured log lines
 
 use experimental 'postderef'; # Not dangerous.  Is accepted without changed.
@@ -159,7 +159,7 @@ sub parse_event_string {
       my $qstring = $2;
 
       $qstring =~ s{
-        ( \\\\ | \\["nr] | (\\x)\{([[:xdigit:]]{1,5})\} | . )
+        ( \\\\ | \\["nr] | (\\x)\{([[:xdigit:]]{1,5})\} )
       }
       {
           $1 eq "\\\\"        ? "\\"
@@ -201,7 +201,7 @@ Log::Fmt - a little parser and emitter of structured log lines
 
 =head1 VERSION
 
-version 3.003
+version 3.004
 
 =head1 OVERVIEW
 
@@ -212,13 +212,13 @@ also do that tolerably-okay parsing for you.
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should
-work on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to
-lower the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 METHODS
 
